@@ -1,5 +1,21 @@
+#' Get Agency Clients from 'MyTarget'
+#'
+#' @inheritParams myTarAuth 
+#' @inheritParams myTarGetAdList 
+#'
+#' @return data frame with agency clients
+#' @export
+#' @seealso {MyTarget API Documenation}{https://target.my.com/doc/api/detailed/#resource_agency_clients}
+#'
+#' @examples
+#' \dontrun{
+#' myTarSetLogin("Your Login")
+#' clients <- myTarGetClientList()
+#' }
 myTarGetClientList <-
-  function(auth = NULL, token_path = getwd(), login = NULL){
+  function(auth = NULL, 
+           login = getOption('rmytarget.login'), 
+           token_path = myTarTokenPath()){
     if (is.null(auth)) {
       auth <- myTarAuth(login = login, token_path = token_path)
     }
